@@ -133,7 +133,7 @@ def test_search(test_db):
         os.path.dirname(os.path.realpath(__file__)), "data", "bom.xml"
     )
     pkg_list = get_pkg_list(test_bom)
-    search_res, pkg_aliases = search_pkgs(test_db, pkg_list)
+    search_res, pkg_aliases = search_pkgs(test_db, "java", pkg_list)
     assert not len(search_res)
 
 
@@ -142,7 +142,7 @@ def test_go_search(test_db):
         os.path.dirname(os.path.realpath(__file__)), "data", "bom-go.xml"
     )
     pkg_list = get_pkg_list(test_bom)
-    search_res, pkg_aliases = search_pkgs(test_db, pkg_list)
+    search_res, pkg_aliases = search_pkgs(test_db, "golang", pkg_list)
     assert not len(search_res)
 
 
@@ -151,7 +151,7 @@ def test_search_webgoat(test_db):
         os.path.dirname(os.path.realpath(__file__)), "data", "bom-webgoat.xml"
     )
     pkg_list = get_pkg_list(test_bom)
-    search_res, pkg_aliases = search_pkgs(test_db, pkg_list)
+    search_res, pkg_aliases = search_pkgs(test_db, "java", pkg_list)
     assert not len(search_res)
 
 
@@ -161,5 +161,5 @@ def test_search_webgoat_json(test_db):
     )
     pkg_list = get_pkg_list(test_bom)
     assert len(pkg_list) == 157
-    search_res, pkg_aliases = search_pkgs(test_db, pkg_list)
+    search_res, pkg_aliases = search_pkgs(test_db, "java", pkg_list)
     assert not len(search_res)
